import { SlideProps } from '@material-ui/core/Slide';
import * as React from 'react';
import { Action } from 'redux';
import { InjectableAction } from 'redux-di-middleware';
import { componentType } from '../services';
import { RootReducerType } from '../store';
import { LocalizationStateType } from '../store/Localization';
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    hostName: string;
    documentIdOrPath: string | number;
    version?: string;
    localization?: Partial<LocalizationStateType>;
    drawerSlideProps?: Partial<SlideProps>;
    loaderImage?: string;
}
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType, ownProps: OwnProps) => {
    isLoading: boolean;
    idOrPath: string | number;
    docViewerError: string | undefined;
    previewImagesError: string | null;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    pollDocumentData: (hostName: string, idOrPath: string | number, version?: string | undefined) => InjectableAction<RootReducerType, Action<any>>;
    setLocalization: (localization: Partial<LocalizationStateType>) => {
        type: string;
        localization: Partial<LocalizationStateType>;
    };
};
declare type docViewerComponentType = componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>;
/**
 * Main document viewer component
 */
declare class DocumentViewer extends React.Component<docViewerComponentType> {
    constructor(props: docViewerComponentType);
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps: this['props']): void;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof DocumentViewer, Pick<{
    isLoading: boolean;
    idOrPath: string | number;
    docViewerError: string | undefined;
    previewImagesError: string | null;
} & {
    pollDocumentData: (hostName: string, idOrPath: string | number, version?: string | undefined) => InjectableAction<RootReducerType, Action<any>>;
    setLocalization: (localization: Partial<LocalizationStateType>) => {
        type: string;
        localization: Partial<LocalizationStateType>;
    };
} & OwnProps, "hostName" | "documentIdOrPath" | "version" | "localization" | "drawerSlideProps" | "loaderImage"> & OwnProps>;
export { connectedComponent as DocumentViewer };
