"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../store");
const Localization_1 = require("../store/Localization");
const DocumentViewerError_1 = require("./DocumentViewerError");
const DocumentViewerLayout_1 = require("./DocumentViewerLayout");
const DocumentViewerLoading_1 = require("./DocumentViewerLoading");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state, ownProps) => {
    return {
        isLoading: state.sensenetDocumentViewer.documentState.isLoading,
        idOrPath: state.sensenetDocumentViewer.documentState.document && state.sensenetDocumentViewer.documentState.document.idOrPath,
        docViewerError: state.sensenetDocumentViewer.documentState.error,
        previewImagesError: state.sensenetDocumentViewer.previewImages.error,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {
    pollDocumentData: store_1.pollDocumentData,
    setLocalization: Localization_1.setLocalization,
};
/**
 * Main document viewer component
 */
class DocumentViewer extends React.Component {
    constructor(props) {
        super(props);
        if (this.props.documentIdOrPath) {
            this.props.pollDocumentData(this.props.hostName, this.props.documentIdOrPath, this.props.version);
        }
        if (this.props.localization) {
            this.props.setLocalization(this.props.localization);
        }
    }
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps) {
        if (this.props.hostName !== newProps.hostName
            || this.props.documentIdOrPath !== newProps.documentIdOrPath
            || this.props.version !== newProps.version) {
            this.props.pollDocumentData(this.props.hostName, this.props.documentIdOrPath, this.props.version);
        }
        if (this.props.localization) {
            this.props.setLocalization(this.props.localization);
        }
    }
    /**
     * renders the component
     */
    render() {
        if (this.props.isLoading) {
            return React.createElement(DocumentViewerLoading_1.DocumentViewerLoading, { image: this.props.loaderImage || './assets/loader.gif' });
        }
        if (this.props.docViewerError || this.props.previewImagesError) {
            return React.createElement(DocumentViewerError_1.DocumentViewerError, { error: this.props.docViewerError || this.props.previewImagesError });
        }
        return (React.createElement(DocumentViewerLayout_1.DocumentViewerLayout, { drawerSlideProps: this.props.drawerSlideProps }, this.props.children));
    }
}
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(DocumentViewer);
exports.DocumentViewer = connectedComponent;
//# sourceMappingURL=DocumentViewer.js.map