import { SlideProps } from '@material-ui/core/Slide';
import React = require('react');
import { componentType } from '../services';
import { RootReducerType } from '../store';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType) => {
    activePages: number[];
    zoomMode: import("../store/Viewer").ZoomMode;
    customZoomLevel: number;
    showThumbnails: boolean;
    fitRelativeZoomLevel: number;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
    setThumbnails: (showThumbnails: boolean) => {
        type: string;
        showThumbnails: boolean;
    };
};
/** Props definition for the Document Viewer layout */
export interface DocumentLayoutOwnProps {
    drawerSlideProps?: Partial<SlideProps>;
}
/** State type definition for the DocumentViewerLayout component */
export interface DocumentLayoutState {
    activePage?: number;
    thumbnaislVisibility: boolean;
}
/**
 * Component for the main DocumentViewer layout
 */
declare class DocumentViewerLayoutComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, DocumentLayoutOwnProps>, DocumentLayoutState> {
    /** the component state */
    state: {
        activePage: number;
        thumbnaislVisibility: boolean;
    };
    /** scrolls the viewer to focus to the page with the provided index */
    scrollTo(index: number, smoothScroll?: boolean): void;
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps: this['props']): void;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof DocumentViewerLayoutComponent, Pick<{
    activePages: number[];
    zoomMode: import("../store/Viewer").ZoomMode;
    customZoomLevel: number;
    showThumbnails: boolean;
    fitRelativeZoomLevel: number;
} & {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
    setThumbnails: (showThumbnails: boolean) => {
        type: string;
        showThumbnails: boolean;
    };
} & DocumentLayoutOwnProps, "drawerSlideProps">>;
export { connectedComponent as DocumentViewerLayout };
