"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Drawer_1 = require("@material-ui/core/Drawer");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../store");
const _1 = require("./");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state) => {
    return {
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        zoomMode: state.sensenetDocumentViewer.viewer.zoomMode,
        customZoomLevel: state.sensenetDocumentViewer.viewer.customZoomLevel,
        showThumbnails: state.sensenetDocumentViewer.viewer.showThumbnails,
        fitRelativeZoomLevel: state.sensenetDocumentViewer.viewer.fitRelativeZoomLevel,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
    setThumbnails: store_1.setThumbnails,
};
/**
 * Component for the main DocumentViewer layout
 */
class DocumentViewerLayoutComponent extends React.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = { activePage: 1, thumbnaislVisibility: this.props.showThumbnails };
    }
    /** scrolls the viewer to focus to the page with the provided index */
    scrollTo(index, smoothScroll = true) {
        this.setState(Object.assign({}, this.state, { activePage: index }), () => {
            const pagesContainer = document.getElementById('sn-document-viewer-pages');
            const activePage = document.getElementById(`Page-${index}`);
            if (pagesContainer && pagesContainer.scrollTo && activePage) {
                pagesContainer.scrollTo({
                    top: activePage.offsetTop - 8,
                    behavior: smoothScroll ? 'smooth' : 'instant',
                });
            }
            const thumbnailsContainer = document.getElementById('sn-document-viewer-thumbnails');
            const activeThumbnail = document.getElementById(`Thumbnail-${index}`);
            if (thumbnailsContainer && thumbnailsContainer.scrollTo && activeThumbnail) {
                thumbnailsContainer.scrollTo({
                    top: activeThumbnail.offsetTop - 16,
                    behavior: 'smooth',
                });
            }
            if (this.props.activePages[0] !== index) {
                this.props.setActivePages([index]);
            }
        });
    }
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps) {
        if (this.props.activePages[0] !== newProps.activePages[0] || this.props.fitRelativeZoomLevel !== newProps.fitRelativeZoomLevel) {
            this.scrollTo(newProps.activePages[0], this.props.fitRelativeZoomLevel === newProps.fitRelativeZoomLevel);
        }
        if (this.props.showThumbnails !== newProps.showThumbnails) {
            if (newProps.showThumbnails) {
                this.setState(Object.assign({}, this.state, { thumbnaislVisibility: true }));
                window.dispatchEvent(new Event('resize'));
            }
            else {
                setTimeout(() => {
                    this.setState(Object.assign({}, this.state, { thumbnaislVisibility: false }));
                    window.dispatchEvent(new Event('resize'));
                }, 200);
            }
        }
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: {
                width: '100%',
                height: '100%',
                display: 'flex',
                flexDirection: 'column',
            } },
            this.props.children,
            React.createElement("div", { style: {
                    display: 'flex',
                    height: '100%',
                    width: '100%',
                    overflow: 'hidden',
                    zIndex: 0,
                    position: 'relative',
                } },
                React.createElement(Drawer_1.default, { variant: 'persistent', open: this.props.showThumbnails, anchor: "left", SlideProps: this.props.drawerSlideProps, PaperProps: { style: { position: 'relative', width: this.state.thumbnaislVisibility ? '200px' : 0, height: '100%', overflow: 'hidden' } } },
                    React.createElement(_1.PageList, { showWidgets: false, style: { minWidth: 200, marginRight: '-16px', paddingRight: 0 }, id: "sn-document-viewer-thumbnails", zoomMode: "fit", fitRelativeZoomLevel: 0, zoomLevel: 1, onPageClick: (ev, index) => this.scrollTo(index), elementNamePrefix: "Thumbnail-", images: "thumbnail", tolerance: 0, padding: 16, activePage: this.state.activePage })),
                React.createElement(_1.PageList, { showWidgets: true, id: "sn-document-viewer-pages", zoomMode: this.props.zoomMode, zoomLevel: this.props.customZoomLevel, fitRelativeZoomLevel: this.props.fitRelativeZoomLevel, onPageClick: (ev, index) => this.scrollTo(index), elementNamePrefix: "Page-", images: "preview", tolerance: 0, padding: 8, activePage: this.state.activePage }))));
    }
}
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(DocumentViewerLayoutComponent);
exports.DocumentViewerLayout = connectedComponent;
//# sourceMappingURL=DocumentViewerLayout.js.map