import React = require('react');
import { DocumentData, PreviewImageData } from '../models';
import { componentType } from '../services';
import { RootReducerType, ZoomMode } from '../store';
import { Action } from 'redux';
import { InjectableAction } from 'redux-di-middleware';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType, ownProps: {
    imageIndex: number;
}) => {
    documentData: DocumentData;
    version: string | undefined;
    page: PreviewImageData;
    activePages: number[];
    showWatermark: boolean;
    pollInterval: number;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    previewAvailable: (documentData: DocumentData, version?: string | undefined, page?: number | undefined) => InjectableAction<RootReducerType, Action<any>>;
};
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    showWidgets: boolean;
    imageIndex: number;
    viewportHeight: number;
    viewportWidth: number;
    elementNamePrefix: string;
    zoomMode: ZoomMode;
    zoomLevel: number;
    fitRelativeZoomLevel: number;
    onClick: (ev: React.MouseEvent<HTMLElement>) => any;
    margin: number;
    image: 'preview' | 'thumbnail';
}
/**
 * State model for the Page component
 */
export interface PageState {
    imgSrc: string;
    pageWidth: number;
    pageHeight: number;
    isActive: boolean;
    imageWidth: string;
    imageHeight: string;
    imageTransform: string;
    zoomRatio: number;
    isPolling: boolean;
}
declare class Page extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>, PageState> {
    private pollPreview?;
    /** the component state */
    state: PageState;
    private stopPolling;
    /** event before the component did unmount */
    componentWillUnmount(): void;
    /**
     * Returns a derived state from the specified props
     * @param props The props for state creation
     */
    static getDerivedStateFromProps(props: Page['props']): PageState;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof Page, Pick<{
    documentData: DocumentData;
    version: string | undefined;
    page: PreviewImageData;
    activePages: number[];
    showWatermark: boolean;
    pollInterval: number;
} & {
    previewAvailable: (documentData: DocumentData, version?: string | undefined, page?: number | undefined) => InjectableAction<RootReducerType, Action<any>>;
} & OwnProps, "margin" | "onClick" | "image" | "zoomMode" | "fitRelativeZoomLevel" | "viewportWidth" | "viewportHeight" | "elementNamePrefix" | "zoomLevel" | "showWidgets" | "imageIndex"> & {
    imageIndex: number;
}>;
export { connectedComponent as Page };
