import * as React from 'react';
import { PreviewImageData } from '../models';
import { componentType } from '../services';
import { RootReducerType, ZoomMode } from '../store';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType) => {
    pages: PreviewImageData[];
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {};
/**
 * Defines the own properties for the PageList component
 */
export interface PageListProps {
    tolerance: number;
    padding: number;
    id: string;
    elementNamePrefix: string;
    zoomMode: ZoomMode;
    zoomLevel: number;
    fitRelativeZoomLevel: number;
    images: 'preview' | 'thumbnail';
    activePage?: number;
    onPageClick: (ev: React.MouseEvent<HTMLElement>, pageIndex: number) => void;
    style?: React.CSSProperties;
    showWidgets: boolean;
}
/**
 * Type definition for the PageList component's State
 */
export interface PageListState {
    marginTop: number;
    marginBottom: number;
    scrollState: number;
    pagesToSkip: number;
    pagesToTake: number;
    viewportWidth: number;
    viewportHeight: number;
    visiblePages: PreviewImageData[];
}
declare class PageList extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, PageListProps>, PageListState> {
    /** the component state */
    state: PageListState;
    private canUpdate;
    private viewPort;
    private onResize;
    private onScroll;
    /** event that will be triggered before mounting the component */
    componentWillMount(): void;
    /** event that will be triggered after mounting the component */
    componentDidMount(): void;
    /** event that will be triggered before unmounting the component */
    componentWillUnmount(): void;
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps: this['props']): void;
    private setupVisiblePages;
    private setupViewPort;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof PageList, Pick<{
    pages: PreviewImageData[];
} & PageListProps, "padding" | "style" | "id" | "zoomMode" | "fitRelativeZoomLevel" | "activePage" | "tolerance" | "elementNamePrefix" | "zoomLevel" | "images" | "onPageClick" | "showWidgets">>;
export { connectedComponent as PageList };
