"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ClickAwayListener_1 = require("@material-ui/core/ClickAwayListener");
const TextField_1 = require("@material-ui/core/TextField");
const Typography_1 = require("@material-ui/core/Typography");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
// tslint:disable-next-line:no-var-requires
const debounce = require('lodash.debounce');
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        documentName: state.sensenetDocumentViewer.documentState.document.documentName,
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        pageCount: state.sensenetDocumentViewer.documentState.document.pageCount,
        gotoPage: state.sensenetDocumentViewer.localization.gotoPage,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
};
/**
 * Document widget component for paging
 */
class DocumentTitlePagerComponent extends React.Component {
    /**
     *
     */
    constructor(props) {
        super(props);
        /** the component state */
        this.state = {
            currentPage: (this.props.activePages[0]) || 1,
            lastPage: this.props.pageCount,
            focused: false,
        };
        this.setPage = debounce(() => {
            this.props.setActivePages([this.state.currentPage]);
        }, 200).bind(this);
        this.submitPageNumber = this.submitPageNumber.bind(this);
    }
    /** triggered when the component will receive props */
    static getDerivedStateFromProps(nextProps, lastState) {
        const newState = Object.assign({}, lastState, { lastPage: nextProps.pageCount });
        return newState;
    }
    /**
     * sets the page to the specified value
     * @param page
     */
    gotoPage(page) {
        let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;
        if (!isNaN(pageInt)) {
            pageInt = Math.max(pageInt, 1);
            pageInt = Math.min(pageInt, this.props.pageCount);
            this.setState({
                currentPage: pageInt,
            }, () => {
                this.setPage();
            });
        }
    }
    submitPageNumber(ev) {
        ev.preventDefault();
        const formData = new FormData(ev.currentTarget);
        const pageNo = formData.get('gotoPage');
        if (pageNo) {
            this.gotoPage(pageNo);
        }
    }
    handleFocused() {
        this.setState(Object.assign({}, this.state, { focused: true }));
    }
    handleBlur() {
        this.setState(Object.assign({}, this.state, { focused: false }));
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement(ClickAwayListener_1.default, { onClickAway: () => this.handleBlur() },
            React.createElement(Typography_1.default, { onClick: () => this.handleFocused(), variant: "title", color: "inherit", style: { cursor: 'pointer', display: 'flex', alignItems: 'center', overflow: 'hidden', margin: '0 2.5em' }, title: this.props.documentName },
                React.createElement("div", { style: { whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis' } },
                    this.props.documentName,
                    "\u00A0"),
                this.state.focused ?
                    React.createElement("form", { onSubmit: this.submitPageNumber },
                        React.createElement(TextField_1.default, { style: { flexShrink: 0 }, title: this.props.gotoPage, defaultValue: this.state.currentPage, onClick: (ev) => this.gotoPage(ev.target.value), type: "number", required: true, InputLabelProps: {
                                shrink: true,
                            }, name: "gotoPage", inputProps: {
                                min: 1, max: this.state.lastPage, style: { textAlign: 'center', color: 'white' },
                            }, margin: "dense" }))
                    :
                        React.createElement("div", { style: { flexShrink: 0 } },
                            this.props.activePages[0],
                            " / ",
                            this.props.pageCount))));
    }
}
exports.DocumentTitlePagerComponent = DocumentTitlePagerComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(DocumentTitlePagerComponent);
exports.DocumentTitlePager = connectedComponent;
//# sourceMappingURL=DocumentTitlePager.js.map