"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const IconButton_1 = require("@material-ui/core/IconButton");
const Save_1 = require("@material-ui/icons/Save");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        saveChanges: state.sensenetDocumentViewer.localization.saveChanges,
        document: state.sensenetDocumentViewer.documentState.document,
        pages: state.sensenetDocumentViewer.previewImages.AvailableImages,
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        canEdit: state.sensenetDocumentViewer.documentState.canEdit,
        hasChanges: state.sensenetDocumentViewer.documentState.hasChanges || state.sensenetDocumentViewer.previewImages.hasChanges,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    save: store_1.saveChanges,
};
/**
 * Document widget component for saving document state
 */
class SaveDocumentComponent extends React.Component {
    save() {
        this.props.canEdit && this.props.save(this.props.document, this.props.pages);
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: { display: 'inline-block' } },
            React.createElement(IconButton_1.default, { disabled: !this.props.hasChanges || !this.props.canEdit, title: this.props.saveChanges },
                React.createElement(Save_1.default, { onClick: () => this.save() }))));
    }
}
exports.SaveDocumentComponent = SaveDocumentComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(SaveDocumentComponent);
exports.SaveWidget = connectedComponent;
//# sourceMappingURL=SaveWidget.js.map