"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Divider_1 = require("@material-ui/core/Divider");
const IconButton_1 = require("@material-ui/core/IconButton");
const Menu_1 = require("@material-ui/core/Menu");
const MenuItem_1 = require("@material-ui/core/MenuItem");
const MobileStepper_1 = require("@material-ui/core/MobileStepper");
const AspectRatio_1 = require("@material-ui/icons/AspectRatio");
const Code_1 = require("@material-ui/icons/Code");
const Error_1 = require("@material-ui/icons/Error");
const ZoomIn_1 = require("@material-ui/icons/ZoomIn");
const ZoomOut_1 = require("@material-ui/icons/ZoomOut");
const ZoomOutMap_1 = require("@material-ui/icons/ZoomOutMap");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        zoomMode: state.sensenetDocumentViewer.viewer.zoomMode,
        customZoomLevel: state.sensenetDocumentViewer.viewer.customZoomLevel,
        localization: {
            zoomMode: state.sensenetDocumentViewer.localization.zoomMode,
            zoomModeFit: state.sensenetDocumentViewer.localization.zoomModeFit,
            zoomModeFitHeight: state.sensenetDocumentViewer.localization.zoomModeFitHeight,
            zoomModeFitWidth: state.sensenetDocumentViewer.localization.zoomModeFitWidth,
            zoomModeOriginalSize: state.sensenetDocumentViewer.localization.zoomModeOriginalSize,
            zooomModeCustom: state.sensenetDocumentViewer.localization.zooomModeCustom,
        },
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setZoomMode: store_1.setZoomMode,
    setZoomLevel: store_1.setCustomZoomLevel,
};
/**
 * Document widget component for modifying the zoom mode / level
 */
class ZoomWidgetComponent extends React.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = { zoomMenuAnchor: undefined };
    }
    openZoomMenu(event) {
        this.setState({ zoomMenuAnchor: event.currentTarget });
    }
    closeZoomMenu(newZoomMode) {
        if (newZoomMode) {
            this.props.setZoomMode(newZoomMode);
        }
        this.setState({ zoomMenuAnchor: undefined });
    }
    zoomIn(ev) {
        ev.preventDefault();
        ev.stopPropagation();
        this.props.setZoomLevel(this.props.customZoomLevel + 1 || 1);
    }
    zoomOut(ev) {
        ev.preventDefault();
        ev.stopPropagation();
        this.props.setZoomLevel(this.props.customZoomLevel - 1 || 0);
    }
    /**
     * renders the component
     */
    render() {
        const localization = this.props.localization;
        return (React.createElement("div", { style: { display: 'inline-block' } },
            React.createElement(IconButton_1.default, { onClick: (ev) => this.openZoomMenu(ev), title: localization.zoomMode }, (() => {
                switch (this.props.zoomMode) {
                    case 'custom':
                        if (this.props.customZoomLevel > 0) {
                            return React.createElement(ZoomIn_1.default, null);
                        }
                        return React.createElement(ZoomOut_1.default, null);
                    case 'fitHeight':
                        return React.createElement(Code_1.default, { style: { transform: 'rotate(90deg)' } });
                    case 'fitWidth':
                        return React.createElement(Code_1.default, null);
                    case 'originalSize':
                        return React.createElement(AspectRatio_1.default, null);
                    case 'fit':
                        return (React.createElement(ZoomOutMap_1.default, null));
                    default:
                        return React.createElement(Error_1.default, null);
                }
            })()),
            React.createElement(Menu_1.default, { id: "zoom-menu", anchorEl: this.state.zoomMenuAnchor, open: Boolean(this.state.zoomMenuAnchor), onClose: () => this.closeZoomMenu() },
                React.createElement(MenuItem_1.default, { onClick: () => this.closeZoomMenu('fit') },
                    React.createElement(ZoomOutMap_1.default, null),
                    " \u00A0 ",
                    localization.zoomModeFit,
                    " "),
                React.createElement(MenuItem_1.default, { onClick: () => this.closeZoomMenu('originalSize') },
                    React.createElement(AspectRatio_1.default, null),
                    "\u00A0 ",
                    localization.zoomModeOriginalSize,
                    " "),
                React.createElement(MenuItem_1.default, { onClick: () => this.closeZoomMenu('fitHeight') },
                    React.createElement(Code_1.default, { style: { transform: 'rotate(90deg)' } }),
                    " \u00A0 ",
                    localization.zoomModeFitHeight,
                    " "),
                React.createElement(MenuItem_1.default, { onClick: () => this.closeZoomMenu('fitWidth') },
                    React.createElement(Code_1.default, null),
                    " \u00A0 ",
                    localization.zoomModeFitWidth,
                    " "),
                React.createElement(Divider_1.default, { light: true }),
                "\u00A0 ",
                localization.zooomModeCustom,
                " ",
                React.createElement("br", null),
                React.createElement(MobileStepper_1.default, { variant: "progress", steps: 6, position: "static", activeStep: this.props.customZoomLevel, nextButton: React.createElement(IconButton_1.default, { disabled: this.props.customZoomLevel === 5, onClickCapture: (ev) => this.zoomIn(ev) },
                        React.createElement(ZoomIn_1.default, null)), backButton: React.createElement(IconButton_1.default, { disabled: this.props.customZoomLevel === 0, onClickCapture: (ev) => this.zoomOut(ev) },
                        React.createElement(ZoomOut_1.default, null)) }))));
    }
}
exports.ZoomWidgetComponent = ZoomWidgetComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(ZoomWidgetComponent);
exports.ZoomModeWidget = connectedComponent;
//# sourceMappingURL=ZoomMode.js.map