import { ZoomMode } from '../store';
/** Dimensions model that defines a specified width and height */
export interface Dimensions {
    width: number;
    height: number;
}
/**
 * Default scale value per step. Adjust this to increase / decrease fit relative zoom per clicks
 */
export declare const fitRelativeZoomLevelScale = 0.05;
/**
 * Helper class for image manipulation
 */
export declare class ImageUtil {
    /**
     * Helper method that normalizes the given angle and returns a value between 0-349 in degrees
     * @param degrees the degrees
     * @returns the normalized value in degrees
     */
    static normalizeDegrees(degrees: number): number;
    /**
     * Helper method that calculates a resized image size
     * @param viewPort The viewport dimensions
     * @param image The image dimensions and the rotation amount
     * @param zoomMode The specified zoom mode
     * @param relativeZoomLevel The relative zoom level if provided
     * @returns The relative image size
     */
    static getImageSize(viewPort: Dimensions, image: Dimensions & {
        rotation: number;
    }, zoomMode: ZoomMode, relativeZoomLevel?: number, fitRelativeZoomLevel?: number): Dimensions;
    /**
     * Helper method that calculates a bounding box for a rotated image
     * @param image The image dimensions
     * @param degrees The rotation in degrees
     * @returns the calculated dimensions and the zoom ratio
     */
    static getRotatedBoundingBoxSize(image: Dimensions, degrees: number): Dimensions & {
        zoomRatio: number;
    };
}
