"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Enums_1 = require("../Enums");
/**
 * Default localization string value
 */
exports.defaultLocalization = {
    rotateDocumentLeft: 'Rotate document left',
    rotateDocumentRight: 'Rotate document right',
    rotatePageLeft: 'Rotate page left',
    rotatePageRight: 'Rotate page right',
    zoomMode: 'Zoom mode',
    zoomModeFit: 'Fit',
    zoomModeOriginalSize: 'Original size',
    zoomModeFitHeight: 'Fit height',
    zoomModeFitWidth: 'Fit width',
    zooomModeCustom: 'Custom',
    toggleRedaction: 'Toggle redaction',
    toggleWatermark: 'Toggle watermark',
    toggleShapes: 'Toggle shapes',
    toggleThumbnails: 'Toggle thumbnails',
    firstPage: 'First page',
    previousPage: 'Previous page',
    gotoPage: 'Goto page',
    nextPage: 'Next page',
    lastPage: 'Last page',
    saveChanges: 'Save changes',
    loadingDocument: 'Preview image generation is in progress',
    errorLoadingDocument: [
        { code: 500, state: Enums_1.PreviewState.Empty, message: 'Ooops! Something went wrong...', details: 'An unexpected error seems to have occured. Why not try refreshing your page? If the page still not working try to check back later.' },
        { code: 404, state: Enums_1.PreviewState.Empty, message: 'Ooops! Something went wrong...', details: `You don't have permission to see this document \r\n The document you are trying to open has been deleted \r\n The document has been moved to another place ` },
        { state: Enums_1.PreviewState.UploadFailure, message: 'Failed to upload', details: '' },
        { state: Enums_1.PreviewState.UploadFailure2, message: 'Failed to upload', details: '' },
        { state: Enums_1.PreviewState.ExtensionFailure, message: 'Failed to generate preview images due to an extension error', details: '' },
        { state: Enums_1.PreviewState.Empty, message: 'The document doesn\'t have any preview images', details: '' },
        { state: Enums_1.PreviewState.NoPreviewProviderEnabled, message: 'There is no preview provider enabled', details: '' },
    ],
    errorLoadingDetails: 'The following error occured during opening a document: ',
    reloadPage: 'Reload page',
    search: 'Search',
    share: 'Share',
    download: 'Download',
    print: 'Print',
};
/**
 * Action that updates the store with new localized values
 * @param localization The new localization values
 */
exports.setLocalization = (localization) => ({
    type: 'SN_DOCVIEWER_SET_LOCALIZATION',
    localization,
});
/**
 * Reducer for localization
 * @param state the current state
 * @param action the action to dispatch
 */
exports.localizationReducer = (state = exports.defaultLocalization, action) => {
    switch (action.type) {
        case 'SN_DOCVIEWER_SET_LOCALIZATION': {
            return Object.assign({}, state, action.localization);
        }
    }
    return state;
};
//# sourceMappingURL=Localization.js.map