import { Reducer } from 'redux';
/**
 * The zoom type definitions
 */
export declare type ZoomMode = 'originalSize' | 'fit' | 'fitHeight' | 'fitWidth' | 'custom';
/**
 * Type model for the Viewer state
 */
export interface ViewerStateType {
    /**
     * The active page(s)
     */
    activePages: number[];
    /**
     * The current zoom mode
     */
    zoomMode: ZoomMode;
    /**
     * The current zoom level
     */
    customZoomLevel: number;
    /**
     * Watermark is on / off
     */
    showWatermark: boolean;
    /**
     * Redaction is on / off
     */
    showRedaction: boolean;
    /**
     * Shapes are on / off
     */
    showShapes: boolean;
    /**
     * Thumbnails on / off
     */
    showThumbnails: boolean;
    /**
     * Zoom level relative to the fitted image size
     */
    fitRelativeZoomLevel: number;
}
/**
 * Action to set the active page(s)
 * @param activePages
 */
export declare const setActivePages: (activePages: number[]) => {
    type: string;
    activePages: number[];
};
/**
 * Action to set the zoom mode
 * @param zoomMode
 */
export declare const setZoomMode: (zoomMode: ZoomMode) => {
    type: string;
    zoomMode: ZoomMode;
};
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 * @param defaultModeOnZero
 */
export declare const setCustomZoomLevel: (customZoomLevel: number, defaultModeOnZero?: ZoomMode) => {
    type: string;
    customZoomLevel: number;
    defaultModeOnZero: ZoomMode;
};
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 * @param defaultModeOnZero
 */
export declare const setFitRelativeZoomLevel: (fitRelativeZoomLevel: number, defaultModeOnZero?: ZoomMode) => {
    type: string;
    fitRelativeZoomLevel: number;
};
/**
 * Action to set the visibility of the watermark
 * @param showWatermark
 */
export declare const setWatermark: (showWatermark: boolean) => {
    type: string;
    showWatermark: boolean;
};
/**
 * Action to set the visibility of the redactions
 * @param showRedaction
 */
export declare const setRedaction: (showRedaction: boolean) => {
    type: string;
    showRedaction: boolean;
};
/**
 * Action to set the visibility of the shapes
 * @param showShapes
 */
export declare const setShapes: (showShapes: boolean) => {
    type: string;
    showShapes: boolean;
};
/**
 * Action to set the visibility of the shapes
 * @param showThumbnails
 */
export declare const setThumbnails: (showThumbnails: boolean) => {
    type: string;
    showThumbnails: boolean;
};
/**
 * Reducer for the Viewer state
 * @param state the current state
 * @param action the dispatched action
 */
export declare const viewerStateReducer: Reducer<ViewerStateType>;
