"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Action to set the active page(s)
 * @param activePages
 */
exports.setActivePages = (activePages) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_PAGE',
    activePages,
});
/**
 * Action to set the zoom mode
 * @param zoomMode
 */
exports.setZoomMode = (zoomMode) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_ZOOM_MODE',
    zoomMode,
});
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 * @param defaultModeOnZero
 */
exports.setCustomZoomLevel = (customZoomLevel, defaultModeOnZero = 'fit') => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_CUSTOM_ZOOM_LEVEL',
    customZoomLevel,
    defaultModeOnZero,
});
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 * @param defaultModeOnZero
 */
exports.setFitRelativeZoomLevel = (fitRelativeZoomLevel, defaultModeOnZero = 'fit') => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_FIT_RELATIVE_ZOOM_LEVEL',
    fitRelativeZoomLevel,
});
/**
 * Action to set the visibility of the watermark
 * @param showWatermark
 */
exports.setWatermark = (showWatermark) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_WATERMARK',
    showWatermark,
});
/**
 * Action to set the visibility of the redactions
 * @param showRedaction
 */
exports.setRedaction = (showRedaction) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_REDACTION',
    showRedaction,
});
/**
 * Action to set the visibility of the shapes
 * @param showShapes
 */
exports.setShapes = (showShapes) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_SHAPES',
    showShapes,
});
/**
 * Action to set the visibility of the shapes
 * @param showThumbnails
 */
exports.setThumbnails = (showThumbnails) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_THUMBNAILS',
    showThumbnails,
});
/**
 * Reducer for the Viewer state
 * @param state the current state
 * @param action the dispatched action
 */
exports.viewerStateReducer = (state = { activePages: [1], zoomMode: 'fit', customZoomLevel: 3, showWatermark: false, showRedaction: true, showShapes: true, showThumbnails: false, fitRelativeZoomLevel: 0 }, action) => {
    switch (action.type) {
        case 'SN_DOCVIEWER_DOCUMENT_RESET_DOCUMENT':
            return Object.assign({}, state, { activePages: [1] });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_PAGE':
            return Object.assign({}, state, { activePages: [...action.activePages] });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_ZOOM_MODE':
            return Object.assign({}, state, { zoomMode: action.zoomMode, customZoomLevel: 0 });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_CUSTOM_ZOOM_LEVEL':
            return Object.assign({}, state, { zoomMode: !action.customZoomLevel ? action.defaultModeOnZero : 'custom', customZoomLevel: action.customZoomLevel });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_WATERMARK':
            return Object.assign({}, state, { showWatermark: action.showWatermark });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_REDACTION':
            return Object.assign({}, state, { showRedaction: action.showRedaction });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_SHAPES':
            return Object.assign({}, state, { showShapes: action.showShapes });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_THUMBNAILS':
            return Object.assign({}, state, { showThumbnails: action.showThumbnails });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_FIT_RELATIVE_ZOOM_LEVEL':
            return Object.assign({}, state, { fitRelativeZoomLevel: action.fitRelativeZoomLevel });
        default:
            return state;
    }
};
//# sourceMappingURL=Viewer.js.map