"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
const redux_1 = require("redux");
const redux_di_middleware_1 = require("redux-di-middleware");
const RootReducer_1 = require("./RootReducer");
/**
 * gets a configuration object for the Store instance
 * @param {DocumentViewerSettings} settings The Settings object for the document viewer instance
 */
exports.getStoreConfig = (settings) => {
    const di = new redux_di_middleware_1.ReduxDiMiddleware();
    di.setInjectable(settings);
    return {
        rootReducer: RootReducer_1.rootReducer,
        preloadedState: { sensenetDocumentViewer: { documentState: { isLoading: true } } },
        enhancer: redux_1.applyMiddleware(di.getMiddleware()),
    };
};
/**
 * returns a Store object for a Document Viewer instance
 * @param {DocumentViewerSettings} settings The Settings object for the document viewer instance
 */
exports.configureStore = (settings) => {
    const config = exports.getStoreConfig(settings);
    return redux_1.createStore(config.rootReducer, config.preloadedState, config.enhancer);
};
__export(require("./Document"));
__export(require("./PreviewImages"));
__export(require("./RootReducer"));
__export(require("./Viewer"));
//# sourceMappingURL=index.js.map